Description: Include cstddef and use std namespace.
 Fix a missing cstddef header file inclusion in some files and use
 of std namespace. This is required in current default gcc flavor.
Author: Francesco Paolo Lovergine <frankie@debian.org>
--- a/src/index/bintree/Root.cpp
+++ b/src/index/bintree/Root.cpp
@@ -20,11 +20,14 @@
 
 #include <cstddef>
 #include <cassert>
+#include <cstddef>
 
 namespace geos {
 namespace index { // geos.index
 namespace bintree { // geos.index.bintree
 
+using namespace std;
+
 double Root::origin=0.0;
 
 void
--- a/src/index/quadtree/Root.cpp
+++ b/src/index/quadtree/Root.cpp
@@ -24,6 +24,7 @@
 #include <geos/geom/Envelope.h>
 
 #include <cassert>
+#include <cstddef>
 
 #ifndef GEOS_DEBUG
 #define GEOS_DEBUG 0
@@ -39,6 +40,8 @@ namespace geos {
 namespace index { // geos.index
 namespace quadtree { // geos.index.quadtree
 
+using namespace std;
+
 // the singleton root quad is centred at the origin.
 //Coordinate* Root::origin=new Coordinate(0.0, 0.0);
 const Coordinate Root::origin(0.0, 0.0);
