Description: Fix FTBFS due to a missing declaration.
Author: Francesco Paolo Lovergine <frankie@debian.org>
Bug-Debian: https://bugs.debian.org/624949
--- a/include/geos/geom/CoordinateSequenceFactory.h
+++ b/include/geos/geom/CoordinateSequenceFactory.h
@@ -23,7 +23,7 @@
 #include <geos/export.h>
 #include <vector>
 
-//#include <geos/geom/Coordinate.h>
+#include <geos/geom/Coordinate.h>
 #include <geos/inline.h>
 
 // Forward declarations
