Description: Include cstddef and use std namespace.
 Fix a missing cstddef header file inclusion in some files and use
 of std namespace. This is required in current default gcc flavor.
Author: Francesco Paolo Lovergine <frankie@debian.org>
--- a/include/geos/operation/valid/SimpleNestedRingTester.h
+++ b/include/geos/operation/valid/SimpleNestedRingTester.h
@@ -24,6 +24,7 @@
 
 #include <cstddef>
 #include <vector>
+#include <cstddef>
 
 #ifdef _MSC_VER
 #pragma warning(push)
@@ -45,6 +46,8 @@ namespace geos {
 namespace operation { // geos::operation
 namespace valid { // geos::operation::valid
 
+using namespace std;
+
 /** \brief
  * Tests whether any of a set of {@link LinearRing}s are
  * nested inside another ring in the set, using a simple O(n^2)
