Description: Include cstddef and use std namespace.
 Fix a missing cstddef header file inclusion in some files and use
 of std namespace. This is required in current default gcc flavor.
Author: Francesco Paolo Lovergine <frankie@debian.org>
--- a/include/geos/simplify/TaggedLineString.h
+++ b/include/geos/simplify/TaggedLineString.h
@@ -28,6 +28,7 @@
 #include <geos/export.h>
 #include <vector>
 #include <memory>
+#include <cstddef>
 
 #ifdef _MSC_VER
 #pragma warning(push)
@@ -51,6 +52,7 @@ namespace geos {
 namespace geos {
 namespace simplify { // geos::simplify
 
+using namespace std;
 
 /** \brief
  *
