Description: Include cstddef and use std namespace.
 Fix a missing cstddef header file inclusion in some files and use
 of std namespace. This is required in current default gcc flavor.
Author: Francesco Paolo Lovergine <frankie@debian.org>
--- a/src/index/bintree/Node.cpp
+++ b/src/index/bintree/Node.cpp
@@ -15,6 +15,7 @@
 
 #include <cstddef>
 #include <cassert>
+#include <cstddef>
 
 #include <geos/index/bintree/Node.h>
 #include <geos/index/bintree/Key.h>
@@ -24,6 +25,8 @@ namespace geos {
 namespace index { // geos.index
 namespace bintree { // geos.index.bintree
 
+using namespace std;
+
 Node*
 Node::createNode(Interval *itemInterval)
 {
--- a/src/geomgraph/Node.cpp
+++ b/src/geomgraph/Node.cpp
@@ -33,6 +33,7 @@
 #include <sstream>
 #include <vector>
 #include <algorithm>
+#include <cstddef>
 
 #ifndef GEOS_DEBUG
 #define GEOS_DEBUG 0
@@ -41,12 +42,13 @@
 #define COMPUTE_Z 1
 #endif
 
-using namespace std;
 using namespace geos::geom;
 
 namespace geos {
 namespace geomgraph { // geos.geomgraph
 
+using namespace std;
+
 /*public*/
 Node::Node(const Coordinate& newCoord, EdgeEndStar* newEdges)
 	:
--- a/src/index/quadtree/Node.cpp
+++ b/src/index/quadtree/Node.cpp
@@ -24,6 +24,7 @@
 #include <string>
 #include <sstream>
 #include <cassert>
+#include <cstddef>
 
 #ifndef GEOS_DEBUG
 #define GEOS_DEBUG 0
@@ -40,6 +41,8 @@ namespace geos {
 namespace index { // geos.index
 namespace quadtree { // geos.index.quadtree
 
+using namespace std;
+
 /* public static */
 std::auto_ptr<Node>
 Node::createNode(const Envelope& env)
