Description: Include cstddef and use std namespace.
 Fix a missing cstddef header file inclusion in some files and use
 of std namespace. This is required in current default gcc flavor.
Author: Francesco Paolo Lovergine <frankie@debian.org>
--- a/include/geos/planargraph/DirectedEdgeStar.h
+++ b/include/geos/planargraph/DirectedEdgeStar.h
@@ -19,6 +19,7 @@
 #include <geos/export.h>
 
 #include <vector>
+#include <cstddef>
 
 #ifdef _MSC_VER
 #pragma warning(push)
@@ -39,6 +40,8 @@ namespace geos {
 namespace geos {
 namespace planargraph { // geos.planargraph
 
+using namespace std;
+
 /// A sorted collection of DirectedEdge which leave a Node in a PlanarGraph.
 class GEOS_DLL DirectedEdgeStar {
 protected:
