Description: Include cstddef and use std namespace.
 Fix a missing cstddef header file inclusion in some files and use
 of std namespace. This is required in current default gcc flavor.
Author: Francesco Paolo Lovergine <frankie@debian.org>
--- a/src/simplify/TaggedLineString.cpp
+++ b/src/simplify/TaggedLineString.cpp
@@ -26,6 +26,7 @@
 
 #include <cassert>
 #include <memory>
+#include <cstddef>
 
 #ifndef GEOS_DEBUG
 #define GEOS_DEBUG 0
@@ -41,6 +42,8 @@ using namespace std;
 namespace geos {
 namespace simplify { // geos::simplify
 
+using namespace std;
+
 /*public*/
 TaggedLineString::TaggedLineString(const geom::LineString* nParentLine,
 			std::size_t nMinimumSize)
